@@ -22,6 +22,7 @@ INSTALLED_APPS = [
     'sequere.backends.redis',
     'sequere.tests',
     'sequere.contrib.user',
+    'sequere.contrib.timeline',
     'sequere',
 ]
 
@@ -30,3 +31,18 @@ SECRET_KEY = 'blabla'
 ROOT_URLCONF = 'sequere.tests.urls'
 
 TEST_RUNNER = 'sequere.tests.runner.DjangoTestSuiteRunner'
+
+BROKER_BACKEND = 'memory'
+
+CELERY_ALWAYS_EAGER = True
+CELERY_EAGER_PROPAGATES_EXCEPTIONS = True
+
+SEQUERE_TIMELINE_NYDUS_CONNECTION = {
+    'backend': 'nydus.db.backends.redis.Redis',
+    'router': 'nydus.db.routers.keyvalue.PartitionRouter',
+    'hosts': {
+        0: {'db': 0},
+        1: {'db': 1},
+        2: {'db': 2},
+    }
+}
